==> quanyi-center-api-1.2.33-cqtb-20250205.021759-2-sources.jar: cn/com/duiba/quanyi/center/api/param/qy/activity/ActivityTemplateWhiteRecordSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.qy.activity;

import cn.com.duiba.quanyi.center.api.param.PageQuery;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 模板活动白名单导入表
 * @author mybatis generator 
 * @date 2024-07-10
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class ActivityTemplateWhiteRecordSearchParam extends PageQuery implements Serializable {
     
    private static final long serialVersionUID = 1720583135042915L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     */
    private Integer logicDelete;

    /**
     * 活动主键, tb_activity.id
     */
    private Long activityId;

    /**
     * 活动主键集合, tb_activity.id
     */
    private List<Long> activityIdList;

    /**
     * 客户号
     */
    private String clientNumber;

    /**
     * 上月达标金额
     */
    private Long lastTargetAmount;

    /**
     * 上月月份
     */
    private String lastMonth;
    /**
     * 手机号
     */
    private String mobile;
    /**
     * 客户号集合
     */
    private List<String> clientNumberList;
    /**
     * 手机号集合
     */
    private List<String> moblieList;

    /**
     * 用户状态 0 发奖用户 1 基础白名单用户
     */
    private Integer  userStatus;

    /**
     * 开始时间
     */
    private Date beginDate;
    /**
     * 结束时间
     */
    private Date endDate;
}

==> quanyi-center-api-1.4.61-cqtb-20251028.021935-2-sources.jar: cn/com/duiba/quanyi/center/api/param/qy/activity/ActivityTemplateWhiteRecordSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.qy.activity;

import cn.com.duiba.quanyi.center.api.enums.activity.ClientNumberTypeEnum;
import cn.com.duiba.quanyi.center.api.param.PageQuery;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 模板活动白名单导入表
 * @author mybatis generator 
 * @date 2024-07-10
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class ActivityTemplateWhiteRecordSearchParam extends PageQuery implements Serializable {
     
    private static final long serialVersionUID = 1720583135042915L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     */
    private Integer logicDelete;

    /**
     * 活动主键, tb_activity.id
     */
    private Long activityId;

    /**
     * 活动主键集合, tb_activity.id
     */
    private List<Long> activityIdList;

    /**
     * 客户号
     */
    private String clientNumber;

    /**
     * 上月达标金额
     */
    private Long lastTargetAmount;

    /**
     * 上月月份
     */
    private String lastMonth;
    /**
     * 手机号
     */
    private String mobile;
    /**
     * 客户号集合
     */
    private List<String> clientNumberList;
    /**
     * 手机号集合
     */
    private List<String> moblieList;

    /**
     * 用户状态 0 发奖用户 1 基础白名单用户
     * @see cn.com.duiba.quanyi.center.api.enums.activity.TemplateWhiteListUserStatusEnum
     */
    private Integer  userStatus;

    /**
     * 开始时间
     */
    private Date beginDate;
    /**
     * 结束时间
     */
    private Date endDate;

    /**
     * 客户号类型
     * {@link ClientNumberTypeEnum}
     */
    private Integer clientNumberType;

    /**
     * 领取标志 0 初始化 1已领取
     */
    private Integer receiveTag;
}
